@@ -6,3 +6,5 @@ Internal utilities for testing, build, pipelines, and logging.
 """
 
 from .testing import stream_handler  # noqa: F401
+from .utils import experimental  # noqa: F401
+from .eyesoff import is_eyesoff_helper  # noqa: F401
